Use Case:  Submit Content for Publication
=========================================

  Actor

    - Content Creator

  Overview

    Non-privileged content creators site need to get review of
    their content before it can be published to all Site Visitors.

  Assumptions

    - Content Creator has logged into the CMF (see "Login to the
      Site":LoginAsMember).

    - Content Creator has created a piece of content which she
      wishes to publish (see "Create Content Object":CreateNewContent).

  Procedure

    1. Navigate to the piece of content you wish to submit for
       publication.

       To retrieve a list of the content you have authored, see
       "View personally authored content":ViewMyContent

    2. Select 'Submit' from the actions box.  The system will
       display the "Submit Content" form:

       **Comment** --
         A textarea for including an optional comment to the
         reviewer.

    3. The system will mark your content as "pending review".
       Reviewers will be notified your content is pending review
       (see "Approve content for publication":ApproveForPublication).
